@@ -78,8 +78,14 @@ private:
   Glib::ustring get_postgresql_utils_version(const SlotProgress& slot_progress);
 
   float get_postgresql_utils_version_as_number(const SlotProgress& slot_progress);
+  
+  void show_active_connections();
 
   bool m_network_shared;
+  
+  //These are only remembered in order to use them to provide debug
+  //information when the PostgreSQL shutdown fails:
+  Glib::ustring m_saved_database_name, m_saved_username, m_saved_password;
 };
 
 } // namespace ConnectionPoolBackends
