@@ -21,9 +21,11 @@
 #ifndef GLOM_DATASTRUCTURE_FIELD_H
 #define GLOM_DATASTRUCTURE_FIELD_H
 
-#include <libgdamm.h>
-#include "translatable_item.h"
-#include "layout/fieldformatting.h"
+#include <libgdamm/column.h>
+#include <libgdamm/holder.h>
+#include <libgdamm/connection.h>
+#include <libglom/data_structure/translatable_item.h>
+#include <libglom/data_structure/layout/fieldformatting.h>
 #include <libglom/sharedptr.h>
 
 //Predicate, for use with std::find_if():
@@ -177,6 +179,7 @@ public:
 
   /** Get the canonical format for a file, for instance for 
    * a default value or for example data.
+   * This does not add quotes for text fields so the caller may need to do that.
    * Note that this does not do any extra escaping such as an XML file might need.
    */
   Glib::ustring to_file_format(const Gnome::Gda::Value& value) const;
@@ -184,6 +187,7 @@ public:
   static Glib::ustring to_file_format(const Gnome::Gda::Value& value, glom_field_type glom_type);
 
   /** Parse the value from the canonical file format. See to_file_format()
+   * This does note remove quotes from text values so the caller may need to do that.
    */
   Gnome::Gda::Value from_file_format(const Glib::ustring& str, bool& success) const;
 
@@ -196,7 +200,7 @@ public:
   /** Get a suitable operator to use when finding records.
    * For instance, == for numbers, or LIKE for text.
    */
-  Glib::ustring sql_find_operator() const;
+  Gnome::Gda::SqlOperatorType sql_find_operator() const;
 
   Glib::ustring get_calculation() const;
   void set_calculation(const Glib::ustring& calculation);
