@@ -25,9 +25,12 @@
 #include <libglom/data_structure/layout/report_parts/layoutitem_fieldsummary.h>
 #include <libglom/data_structure/glomconversions.h>
 
+#include <giomm/file.h>
+#include <glibmm/convert.h>
+#include <glibmm/fileutils.h>
+#include <glibmm/miscutils.h>
 #include <glibmm/i18n.h>
 
-#include <giomm/file.h>
 
 #include <string.h> // for strchr
 #include <sstream> //For stringstream
@@ -1015,50 +1018,58 @@ bool Utils::file_exists(const Glib::RefPtr<Gio::File>& file)
   }
 }
 
-std::string Utils::sqlbuilder_get_full_query(
-    const Glib::RefPtr<Gnome::Gda::Connection>& connection,
-    const Glib::ustring& query,
-    const Glib::RefPtr<const Gnome::Gda::Set>& params)
+//TODO: This is a duplicate of the one in db_utils.cc:
+//Merge all db utilities into db_utils in glom 1.22:
+static Glib::RefPtr<Gnome::Gda::Connection> get_connection()
 {
-  Glib::ustring result = "glom_query_not_parsed";
-
+  sharedptr<SharedConnection> sharedconnection;
   try
   {
-    Glib::RefPtr<Gnome::Gda::SqlParser> parser = connection->create_parser();
-    if(parser)
-    {
-      Glib::RefPtr<Gnome::Gda::Statement> stmt = parser->parse_string(query);
-      if(stmt)
-        result = stmt->to_sql(params);
-    }
+     sharedconnection = ConnectionPool::get_and_connect();
   }
-  catch(const Glib::Exception& ex)
+  catch (const Glib::Error& error)
   {
-    std::cerr << G_STRFUNC << ": exception while parsing query: " << ex.what() << std::endl;
-  }
-  catch(const std::exception& ex)
-  {
-    std::cerr << G_STRFUNC << ": exception while parsing query: " << ex.what() << std::endl;
+    std::cerr << G_STRFUNC << ": " << error.what() << std::endl;
   }
 
-  //Convert to something that std::cout should be able to handle.
-  const Glib::ScopedPtr<char> buf(g_convert_with_fallback(
-    result.raw().data(), result.raw().size(),
-    "ISO-8859-1", "UTF-8",
-    (char*)"?",
-    0, 0, 0));
-  return std::string(buf.get());
+  if(!sharedconnection)
+  {
+    std::cerr << G_STRFUNC << ": No connection yet." << std::endl;
+    return Glib::RefPtr<Gnome::Gda::Connection>(0);
+  }
+
+  Glib::RefPtr<Gnome::Gda::Connection> gda_connection = sharedconnection->get_gda_connection();
+
+  return gda_connection;
 }
 
 std::string Utils::sqlbuilder_get_full_query(
   const Glib::RefPtr<const Gnome::Gda::SqlBuilder>& builder)
 {
+  Glib::RefPtr<Gnome::Gda::Connection> connection = get_connection();
+  if(!connection)
+  {
+    //TODO: Just use the correct provider, without an actual connection?
+    std::cerr << G_STRFUNC << ": There is no connection, so the SQL statement might not be created correctly." << std::endl;
+  }
+
   Glib::ustring result = "glom_query_not_parsed";
 
   try
   {
     Glib::RefPtr<Gnome::Gda::Statement> stmt = builder->get_statement();
-    if(stmt)
+    if(!stmt)
+    {
+      std::cerr << G_STRFUNC << ": builder->get_statement() failed." << std::endl;
+      return result;
+    }
+
+    if(connection)
+    {
+      result = connection->statement_to_sql(stmt,
+          Gnome::Gda::STATEMENT_SQL_PARAMS_AS_VALUES | Gnome::Gda::STATEMENT_SQL_PRETTY);
+    }
+    else
       result = stmt->to_sql();
   }
   catch(const Gnome::Gda::SqlError& ex)
@@ -1148,6 +1159,48 @@ Gnome::Gda::SqlExpr Utils::get_find_where_clause_quick(const Document* document,
   }
 }
 
+Glib::RefPtr<Gnome::Gda::SqlBuilder> Utils::build_sql_update_with_where_clause(
+  const Glib::ustring& table_name,
+  const sharedptr<const Field>& field, const Gnome::Gda::Value& value,
+  const Gnome::Gda::SqlExpr& where_clause)
+{
+  Glib::RefPtr<Gnome::Gda::SqlBuilder> builder;
+
+  if(!field || field->get_name().empty())
+  {
+    std::cerr << "field was null or its name was empty." << std::endl;
+    return builder;
+  }
+
+  if(table_name.empty())
+  {
+    std::cerr << "table_name was empty." << std::endl;
+    return builder;
+  }
+
+  //Build the whole SQL statement:
+  try
+  {
+    builder = Gnome::Gda::SqlBuilder::create(Gnome::Gda::SQL_STATEMENT_UPDATE);
+    builder->set_table(table_name);
+
+    builder->add_field_value_as_value(field->get_name(), value);
+
+    //Add the WHERE clause:
+    if(!where_clause.empty())
+    {
+      const int id = builder->import_expression(where_clause);
+      builder->set_where(id);
+    }
+  }
+  catch(const Glib::Error& ex)
+  {
+    std::cerr << G_STRFUNC << ": Exception: " << ex.what() << std::endl;
+  }
+
+  return builder;
+}
+
 bool Utils::delete_directory(const Glib::RefPtr<Gio::File>& directory)
 {
   if(!(directory->query_exists()))
@@ -1298,4 +1351,74 @@ Glib::ustring Utils::get_list_of_layout_items_for_display(const sharedptr<const
     return Glib::ustring();
 }
 
+std::string Utils::get_temp_file_path(const std::string& prefix, const std::string& extension)
+{
+  //Get a temporary file path:
+  std::string filepath;
+  try
+  {
+    const std::string prefix_pattern = prefix + "XXXXXX" + extension;
+    const int filehandle = Glib::file_open_tmp(filepath, prefix);
+    ::close(filehandle);
+  }
+  catch(const Glib::Error& ex)
+  {
+    std::cerr << G_STRFUNC << ": Glib::file_open_tmp() failed" << std::endl;
+    return filepath;
+  }
+  
+  if(filepath.empty())
+  {
+    std::cerr << G_STRFUNC << ": Glib::file_open_tmp() returned an empty filepath" << std::endl;
+  }
+
+  return filepath;
+}
+
+Glib::ustring Utils::get_temp_file_uri(const std::string& prefix, const std::string& extension)
+{
+  try
+  {
+    const std::string filepath = get_temp_file_path(prefix, extension);
+    return Glib::filename_to_uri(filepath);
+  }
+  catch(const Glib::Error& ex)
+  {
+    std::cerr << G_STRFUNC << ": Exception from filename_to_uri(): " << ex.what() << std::endl;
+    return std::string();
+  }
+}
+
+std::string Utils::get_temp_directory_path(const std::string& prefix)
+{
+  std::string result;
+
+  const std::string pattern = Glib::build_filename(
+    Glib::get_tmp_dir(), prefix + "XXXXXX");
+
+  //We must copy the pattern, because mkdtemp() modifies it:
+  char* c_pattern = g_strdup(pattern.c_str());
+  
+  const char* filepath = g_mkdtemp(c_pattern);
+  if(filepath)
+    result = filepath;
+
+  return result;
+}
+
+Glib::ustring Utils::get_temp_directory_uri(const std::string& prefix)
+{
+  try
+  {
+    const std::string filepath = get_temp_directory_path(prefix);
+    return Glib::filename_to_uri(filepath);
+  }
+  catch(const Glib::Error& ex)
+  {
+    std::cerr << G_STRFUNC << ": Exception from filename_to_uri(): " << ex.what() << std::endl;
+    return Glib::ustring();
+  }
+}
+
+
 } //namespace Glom
