@@ -25,8 +25,11 @@
 #include <libglom/data_structure/glomconversions.h> //For util_build_sql
 #include <libglom/utils.h>
 #include <libglom/db_utils.h>
+#include <libgdamm/datamodel.h>
+#include <libgdamm/dataaccesswrapper.h>
+#include <libgdamm/datamodelarray.h>
 
-#include "glom/application.h"
+#include <glom/application.h>
 
 namespace Glom
 {
@@ -205,6 +208,9 @@ DbTreeModel::DbTreeModel(const FoundSet& found_set, const type_vec_const_layout_
       sharedptr<const LayoutItem_Field> item_field = sharedptr<const LayoutItem_Field>::cast_dynamic(*iter);
       if(item_field)
       {
+        if(item_field->get_glom_type() == Field::TYPE_INVALID)
+          std::cerr << G_STRFUNC << ": field has invalid type. field name: " << item_field->get_name() << std::endl;
+
         m_column_fields.push_back(item_field);
       }
     }
@@ -364,7 +370,7 @@ bool DbTreeModel::refresh_from_database(const FoundSet& found_set)
       //This doesn't work with cursor-based models: const int count = m_gda_datamodel->get_n_rows();
       //because rows count is -1 until we have iterated to the last row.
       Glib::RefPtr<Gnome::Gda::SqlBuilder> sql_query_without_sort = Utils::build_sql_select_with_where_clause(m_found_set.m_table_name, m_column_fields, m_found_set.m_where_clause, m_found_set.m_extra_join, type_sort_clause());
-      const int count = Base_DB::count_rows_returned_by(sql_query_without_sort);
+      const int count = DbUtils::count_rows_returned_by(sql_query_without_sort);
       if(count < 0)
       {
         std::cerr << G_STRFUNC << ": count is < 0" << std::endl;
