@@ -59,7 +59,8 @@ Dialog_Layout_Details::Dialog_Layout_Details(BaseObjectType* cobject, const Glib
   m_button_edit(0),
   m_label_table_name(0),
   m_hbox_rows_count(0),
-  m_spinbutton_rows_count(0)
+  m_spinbutton_rows_count_min(0),
+  m_spinbutton_rows_count_max(0)
 {
   // Get the alternate sets of widgets, only one of which should be shown:
   // Derived classes will hide one and show the other:
@@ -80,7 +81,8 @@ Dialog_Layout_Details::Dialog_Layout_Details(BaseObjectType* cobject, const Glib
   
   //This is only shown in Dialog_Layout_List_Related:
   builder->get_widget("hbox_rows_count", m_hbox_rows_count);
-  builder->get_widget("spinbutton_rows_count", m_spinbutton_rows_count);
+  builder->get_widget("spinbutton_rows_count_min", m_spinbutton_rows_count_min);
+  builder->get_widget("spinbutton_rows_count_max", m_spinbutton_rows_count_max);
   m_hbox_rows_count->hide();
   
   builder->get_widget("treeview_fields", m_treeview_fields);
@@ -1116,9 +1118,9 @@ void Dialog_Layout_Details::on_cell_data_name(Gtk::CellRenderer* renderer, const
       {
         sharedptr<LayoutItem_CalendarPortal> layout_calendar = sharedptr<LayoutItem_CalendarPortal>::cast_dynamic(layout_portal);
         if(layout_calendar)
-          markup = _("Related Calendar: ") + layout_portal->get_relationship_name();
+          markup = Glib::ustring::compose(_("Related Calendar: %1"), layout_portal->get_relationship_name());
         else
-          markup = _("Related List: ") + layout_portal->get_relationship_name();
+          markup = Glib::ustring::compose(_("Related List: %1"), layout_portal->get_relationship_name());
       }
       else
       {
@@ -1135,7 +1137,7 @@ void Dialog_Layout_Details::on_cell_data_name(Gtk::CellRenderer* renderer, const
           sharedptr<LayoutItem_Field> layout_item_field = sharedptr<LayoutItem_Field>::cast_dynamic(layout_item);
           if(layout_item_field)
           {
-            markup = _("Field: ") + layout_item_field->get_layout_display_name(); //TODO: Put this all in a sprintf-style string so it can be translated properly.
+            markup = Glib::ustring::compose(_("Field: %1"), layout_item_field->get_layout_display_name());
 
             //Just for debugging:
             //if(!row[m_model_items->m_columns.m_col_editable])
