@@ -24,10 +24,14 @@
 #include <glom/utils_ui.h>
 #include <glom/application.h>
 #include <glom/print_layout/print_layout_utils.h>
+#include <gtkmm/radioaction.h>
+#include <gtkmm/printsettings.h>
+#include <gtkmm/stock.h>
+#include <gtkmm/grid.h>
+#include <gtkmm/printoperation.h>
 #include <libglom/data_structure/layout/layoutitem_line.h>
 #include <libglom/data_structure/layout/layoutitem_portal.h>
-#include <libglom/utils.h> //For bold_message()).
-#include <gtkmm/scrolledwindow.h>
+#include <libglom/utils.h> //For bold_message()).>
 #include <glibmm/i18n.h>
 
 #include <iostream>
@@ -128,7 +132,7 @@ Window_PrintLayout_Edit::Window_PrintLayout_Edit(BaseObjectType* cobject, const
   gimp_ruler_set_unit(m_hruler, GIMP_UNIT_MM);
   gimp_ruler_set_unit(m_vruler, GIMP_UNIT_MM);
 
-  builder->get_widget("handle_box", m_palette_handle_box);
+  builder->get_widget("toolpalette_box", m_palette_box);
 
 
   builder->get_widget("button_close", m_button_close);
@@ -159,7 +163,7 @@ Window_PrintLayout_Edit::Window_PrintLayout_Edit(BaseObjectType* cobject, const
 
   init_menu();
 
-  m_palette_handle_box->add(m_toolbar);
+  m_palette_box->add(m_toolbar); //TODO: Just put the GtkToolPalette in the glade file and use get_widget_derived()?
   m_toolbar.show();
 
   m_scrolled_window.get_hadjustment()->signal_changed().connect(
