@@ -62,7 +62,7 @@ CanvasGroupDbTable::CanvasGroupDbTable(const Glib::ustring& table_name, const Gl
   Glib::RefPtr<CanvasTextMovable> m_text = CanvasTextMovable::create(title,
     x + margin, y + margin, m_table_width - margin*2,
     Goocanvas::ANCHOR_NORTH_WEST);
-  m_text->property_font() = "sans 10";
+  m_text->property_font() = "Sans 12"; //TODO: Let the user specify this.
   m_text->property_use_markup() = true;
   m_text->set_movement_allowed(false, false); //Move only as part of the parent group.
   add_child(m_text);
@@ -93,7 +93,7 @@ CanvasGroupDbTable::CanvasGroupDbTable(const Glib::ustring& table_name, const Gl
     Glib::RefPtr<CanvasTextMovable> text_item = CanvasTextMovable::create(title, 
       x + margin, y + margin + field_y, m_table_width - margin*2,
       Goocanvas::ANCHOR_NORTH_WEST);
-    text_item->property_font() = "sans 10";
+    text_item->property_font() = "Sans 12"; //TODO: Let the user specify this.
     text_item->property_use_markup() = true;
     text_item->set_movement_allowed(false, false); //Move only as part of the parent group.
     add_child(text_item);
