@@ -23,6 +23,10 @@
 
 #include <glom/mode_design/layout/dialog_layout.h>
 #include <libglom/data_structure/report.h>
+#include <gtkmm/notebook.h>
+#include <gtkmm/checkbutton.h>
+#include <gtkmm/label.h>
+#include <gtkmm/entry.h>
 #include "treestore_report_layout.h"
 //#include <libglom/data_structure/layout/layoutitem.h>
 //#include <libglom/sharedptr.h>
@@ -92,7 +96,7 @@ private:
 
   void on_cell_data_available_part(Gtk::CellRenderer* renderer, const Gtk::TreeModel::iterator& iter);
 
-  void on_notebook_switch_page(GtkNotebookPage*, guint);
+  void on_notebook_switch_page(Gtk::Widget*, guint);
 
   void fill_report_parts(sharedptr<LayoutGroup>& group, const Glib::RefPtr<const type_model> parts_model);
 
@@ -124,6 +128,7 @@ private:
 
   Glib::ustring m_name_original;
   sharedptr<Report> m_report;
+  sigc::connection m_signal_connection;
 };
 
 } //namespace Glom
