@@ -1,5 +1,3 @@
-#include <gtkmm.h>
-#include <gtksourceviewmm/init.h>
 #include <glom/glade_utils.h>
 #include <glom/application.h>
 #include <glom/dialog_existing_or_new.h>
@@ -16,6 +14,26 @@
 #include <glom/utility_widgets/dialog_flowtable.h>
 #include <glom/utility_widgets/dialog_image_load_progress.h>
 #include <glom/utility_widgets/dialog_image_save_progress.h>
+/* Glom
+ *
+ * Copyright (C) 2010-2011 Murray Cumming
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
+ * published by the Free Software Foundation; either version 2 of the
+ * License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public
+ * License along with this program; if not, write to the
+ * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ * Boston, MA 02111-1307, USA.
+ */
+ 
 #include <glom/mode_design/layout/dialog_choose_field.h>
 #include <glom/mode_design/dialog_add_related_table.h>
 #include <glom/mode_design/layout/layout_item_dialogs/dialog_buttonscript.h>
@@ -52,9 +70,13 @@
 #include <glom/mode_design/users/dialog_choose_user.h>
 #include <glom/mode_design/users/dialog_user.h>
 #include <glom/mode_design/print_layouts/dialog_text_formatting.h>
-#include <glom/dialog_progress_creating.h>
 #include <glom/dialog_invalid_data.h>
+#include <gtkmm/builder.h>
+#include <gtkmm/main.h>
+#include <gtksourceviewmm/init.h>
 
+const int GLOM_MAX_WINDOW_WIDTH = 800;
+const int GLOM_MAX_WINDOW_HEIGHT = 600;
 
 template<class T_Widget>
 bool instantiate_widget()
@@ -68,7 +90,24 @@ bool instantiate_widget()
     exit(EXIT_FAILURE); //Make sure that our test case fails.
     return false;
   }
-
+  
+  //Also check that it is not too big for our target minimum screen size.
+  //Note that this is not testing all .glade files, or all windows (some not using glade),
+  //and doesn't even reliably check all uses of .glade files,
+  //but hopefully it will catch some problems:
+  widget->show();
+  const Gtk::Allocation allocation = widget->get_allocation();
+ 
+  if( (allocation.get_height() > GLOM_MAX_WINDOW_HEIGHT) ||
+    (allocation.get_width() > GLOM_MAX_WINDOW_WIDTH))
+  {
+    std::cerr << "Test: The window/widget is too big: " << T_Widget::glade_id << std::endl;
+    std::cerr << "  height=" << allocation.get_height() << std::endl; 
+    std::cerr << "  width=" << allocation.get_width() << std::endl;
+    std::cerr << "  (Ignored, though it should be fixed.)" << std::endl; 
+    //TODO: Uncomment this when all the windows are small enough: exit(EXIT_FAILURE); //Make sure that our test case fails.
+  }
+  
   delete widget;
   return true;
 }
@@ -91,7 +130,6 @@ int main(int argc, char *argv[])
   instantiate_widget<Dialog_InvalidData>();
   instantiate_widget<DialogImageLoadProgress>();
   instantiate_widget<DialogImageSaveProgress>();
-  instantiate_widget<Dialog_ProgressCreating>();
 
   //Developer mode UI:
   instantiate_widget<Box_Print_Layouts>();
